'''_3226.py

BevelDifferentialGearPowerFlow
'''


from mastapy.system_model.part_model.gears import _2054
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6057
from mastapy.gears.rating.bevel import _341
from mastapy.gears.rating.zerol_bevel import _173
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating.straight_bevel import _203
from mastapy.gears.rating.spiral_bevel import _206
from mastapy.system_model.analyses_and_results.power_flows import _3231
from mastapy._internal.python_net import python_net_import

_BEVEL_DIFFERENTIAL_GEAR_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows', 'BevelDifferentialGearPowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelDifferentialGearPowerFlow',)


class BevelDifferentialGearPowerFlow(_3231.BevelGearPowerFlow):
    '''BevelDifferentialGearPowerFlow

    This is a mastapy class.
    '''

    TYPE = _BEVEL_DIFFERENTIAL_GEAR_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelDifferentialGearPowerFlow.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2054.BevelDifferentialGear':
        '''BevelDifferentialGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2054.BevelDifferentialGear)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6057.BevelDifferentialGearLoadCase':
        '''BevelDifferentialGearLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6057.BevelDifferentialGearLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None

    @property
    def component_detailed_analysis(self) -> '_341.BevelGearRating':
        '''BevelGearRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_341.BevelGearRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def component_detailed_analysis_of_type_zerol_bevel_gear_rating(self) -> '_173.ZerolBevelGearRating':
        '''ZerolBevelGearRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _173.ZerolBevelGearRating.TYPE not in self.wrapped.ComponentDetailedAnalysis.__class__.__mro__:
            raise CastException('Failed to cast component_detailed_analysis to ZerolBevelGearRating. Expected: {}.'.format(self.wrapped.ComponentDetailedAnalysis.__class__.__qualname__))

        return constructor.new(_173.ZerolBevelGearRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def component_detailed_analysis_of_type_straight_bevel_gear_rating(self) -> '_203.StraightBevelGearRating':
        '''StraightBevelGearRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _203.StraightBevelGearRating.TYPE not in self.wrapped.ComponentDetailedAnalysis.__class__.__mro__:
            raise CastException('Failed to cast component_detailed_analysis to StraightBevelGearRating. Expected: {}.'.format(self.wrapped.ComponentDetailedAnalysis.__class__.__qualname__))

        return constructor.new(_203.StraightBevelGearRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None

    @property
    def component_detailed_analysis_of_type_spiral_bevel_gear_rating(self) -> '_206.SpiralBevelGearRating':
        '''SpiralBevelGearRating: 'ComponentDetailedAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _206.SpiralBevelGearRating.TYPE not in self.wrapped.ComponentDetailedAnalysis.__class__.__mro__:
            raise CastException('Failed to cast component_detailed_analysis to SpiralBevelGearRating. Expected: {}.'.format(self.wrapped.ComponentDetailedAnalysis.__class__.__qualname__))

        return constructor.new(_206.SpiralBevelGearRating)(self.wrapped.ComponentDetailedAnalysis) if self.wrapped.ComponentDetailedAnalysis else None



'''_5297.py

CylindricalGearSetGearWhineAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2065
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6095
from mastapy.system_model.analyses_and_results.system_deflections import _2253, _2254, _2255
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.gear_whine_analyses import _5295, _5296, _5321
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_SET_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses', 'CylindricalGearSetGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearSetGearWhineAnalysis',)


class CylindricalGearSetGearWhineAnalysis(_5321.GearSetGearWhineAnalysis):
    '''CylindricalGearSetGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_SET_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearSetGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_2065.CylindricalGearSet':
        '''CylindricalGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2065.CylindricalGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6095.CylindricalGearSetLoadCase':
        '''CylindricalGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6095.CylindricalGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2253.CylindricalGearSetSystemDeflection':
        '''CylindricalGearSetSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2253.CylindricalGearSetSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_cylindrical_gear_set_system_deflection_timestep(self) -> '_2254.CylindricalGearSetSystemDeflectionTimestep':
        '''CylindricalGearSetSystemDeflectionTimestep: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2254.CylindricalGearSetSystemDeflectionTimestep.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to CylindricalGearSetSystemDeflectionTimestep. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2254.CylindricalGearSetSystemDeflectionTimestep)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_cylindrical_gear_set_system_deflection_with_ltca_results(self) -> '_2255.CylindricalGearSetSystemDeflectionWithLTCAResults':
        '''CylindricalGearSetSystemDeflectionWithLTCAResults: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2255.CylindricalGearSetSystemDeflectionWithLTCAResults.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to CylindricalGearSetSystemDeflectionWithLTCAResults. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2255.CylindricalGearSetSystemDeflectionWithLTCAResults)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def gears_gear_whine_analysis(self) -> 'List[_5295.CylindricalGearGearWhineAnalysis]':
        '''List[CylindricalGearGearWhineAnalysis]: 'GearsGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsGearWhineAnalysis, constructor.new(_5295.CylindricalGearGearWhineAnalysis))
        return value

    @property
    def cylindrical_gears_gear_whine_analysis(self) -> 'List[_5295.CylindricalGearGearWhineAnalysis]':
        '''List[CylindricalGearGearWhineAnalysis]: 'CylindricalGearsGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalGearsGearWhineAnalysis, constructor.new(_5295.CylindricalGearGearWhineAnalysis))
        return value

    @property
    def meshes_gear_whine_analysis(self) -> 'List[_5296.CylindricalGearMeshGearWhineAnalysis]':
        '''List[CylindricalGearMeshGearWhineAnalysis]: 'MeshesGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshesGearWhineAnalysis, constructor.new(_5296.CylindricalGearMeshGearWhineAnalysis))
        return value

    @property
    def cylindrical_meshes_gear_whine_analysis(self) -> 'List[_5296.CylindricalGearMeshGearWhineAnalysis]':
        '''List[CylindricalGearMeshGearWhineAnalysis]: 'CylindricalMeshesGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.CylindricalMeshesGearWhineAnalysis, constructor.new(_5296.CylindricalGearMeshGearWhineAnalysis))
        return value



'''_2214.py

BeltConnectionSystemDeflection
'''


from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets import _1832
from mastapy.system_model.analyses_and_results.static_loads import _6055
from mastapy.system_model.analyses_and_results.power_flows import _3223
from mastapy.system_model.analyses_and_results.system_deflections import _2275
from mastapy._internal.python_net import python_net_import

_BELT_CONNECTION_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'BeltConnectionSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltConnectionSystemDeflection',)


class BeltConnectionSystemDeflection(_2275.InterMountableComponentConnectionSystemDeflection):
    '''BeltConnectionSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _BELT_CONNECTION_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltConnectionSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def extension(self) -> 'float':
        '''float: 'Extension' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Extension

    @property
    def extension_including_pre_tension(self) -> 'float':
        '''float: 'ExtensionIncludingPreTension' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ExtensionIncludingPreTension

    @property
    def force_in_loa(self) -> 'float':
        '''float: 'ForceInLOA' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ForceInLOA

    @property
    def connection_design(self) -> '_1832.BeltConnection':
        '''BeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1832.BeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6055.BeltConnectionLoadCase':
        '''BeltConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6055.BeltConnectionLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None

    @property
    def power_flow_results(self) -> '_3223.BeltConnectionPowerFlow':
        '''BeltConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_3223.BeltConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None



'''_317.py

ToothFlankFractureAnalysisContactPoint
'''


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.gears.rating.cylindrical.iso6336 import _318
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_TOOTH_FLANK_FRACTURE_ANALYSIS_CONTACT_POINT = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336', 'ToothFlankFractureAnalysisContactPoint')


__docformat__ = 'restructuredtext en'
__all__ = ('ToothFlankFractureAnalysisContactPoint',)


class ToothFlankFractureAnalysisContactPoint(_0.APIBase):
    '''ToothFlankFractureAnalysisContactPoint

    This is a mastapy class.
    '''

    TYPE = _TOOTH_FLANK_FRACTURE_ANALYSIS_CONTACT_POINT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ToothFlankFractureAnalysisContactPoint.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def effective_case_depth(self) -> 'float':
        '''float: 'EffectiveCaseDepth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EffectiveCaseDepth

    @property
    def maximum_residual_stress(self) -> 'float':
        '''float: 'MaximumResidualStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumResidualStress

    @property
    def hertzian_contact_stress(self) -> 'float':
        '''float: 'HertzianContactStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HertzianContactStress

    @property
    def local_normal_radius_of_relative_curvature(self) -> 'float':
        '''float: 'LocalNormalRadiusOfRelativeCurvature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LocalNormalRadiusOfRelativeCurvature

    @property
    def half_of_hertzian_contact_width(self) -> 'float':
        '''float: 'HalfOfHertzianContactWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HalfOfHertzianContactWidth

    @property
    def transverse_thickness_at_the_diameter_corresponding_to_the_middle_between_b_and_d(self) -> 'float':
        '''float: 'TransverseThicknessAtTheDiameterCorrespondingToTheMiddleBetweenBAndD' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseThicknessAtTheDiameterCorrespondingToTheMiddleBetweenBAndD

    @property
    def maximum_material_exposure(self) -> 'float':
        '''float: 'MaximumMaterialExposure' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumMaterialExposure

    @property
    def location(self) -> 'str':
        '''str: 'Location' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Location

    @property
    def analysis_point_with_maximum_local_material_exposure(self) -> '_318.ToothFlankFractureAnalysisPoint':
        '''ToothFlankFractureAnalysisPoint: 'AnalysisPointWithMaximumLocalMaterialExposure' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_318.ToothFlankFractureAnalysisPoint)(self.wrapped.AnalysisPointWithMaximumLocalMaterialExposure) if self.wrapped.AnalysisPointWithMaximumLocalMaterialExposure else None

    @property
    def watch_points(self) -> 'List[_318.ToothFlankFractureAnalysisPoint]':
        '''List[ToothFlankFractureAnalysisPoint]: 'WatchPoints' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WatchPoints, constructor.new(_318.ToothFlankFractureAnalysisPoint))
        return value



'''_139.py

MicroGeometryInputTypes
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_MICRO_GEOMETRY_INPUT_TYPES = python_net_import('SMT.MastaAPI.Gears', 'MicroGeometryInputTypes')


__docformat__ = 'restructuredtext en'
__all__ = ('MicroGeometryInputTypes',)


class MicroGeometryInputTypes(Enum):
    '''MicroGeometryInputTypes

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _MICRO_GEOMETRY_INPUT_TYPES

    __hash__ = None

    FACTORS = 0
    MEASUREMENTS = 1



'''_5976.py

ImportedFEComponentCompoundDynamicAnalysis
'''


from typing import List

from mastapy.system_model.part_model import _2001
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.dynamic_analyses import _5855
from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import _5919
from mastapy._internal.python_net import python_net_import

_IMPORTED_FE_COMPONENT_COMPOUND_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses.Compound', 'ImportedFEComponentCompoundDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ImportedFEComponentCompoundDynamicAnalysis',)


class ImportedFEComponentCompoundDynamicAnalysis(_5919.AbstractShaftOrHousingCompoundDynamicAnalysis):
    '''ImportedFEComponentCompoundDynamicAnalysis

    This is a mastapy class.
    '''

    TYPE = _IMPORTED_FE_COMPONENT_COMPOUND_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ImportedFEComponentCompoundDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2001.ImportedFEComponent':
        '''ImportedFEComponent: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2001.ImportedFEComponent)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def load_case_analyses_ready(self) -> 'List[_5855.ImportedFEComponentDynamicAnalysis]':
        '''List[ImportedFEComponentDynamicAnalysis]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_5855.ImportedFEComponentDynamicAnalysis))
        return value

    @property
    def component_dynamic_analysis_load_cases(self) -> 'List[_5855.ImportedFEComponentDynamicAnalysis]':
        '''List[ImportedFEComponentDynamicAnalysis]: 'ComponentDynamicAnalysisLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentDynamicAnalysisLoadCases, constructor.new(_5855.ImportedFEComponentDynamicAnalysis))
        return value

    @property
    def planetaries(self) -> 'List[ImportedFEComponentCompoundDynamicAnalysis]':
        '''List[ImportedFEComponentCompoundDynamicAnalysis]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(ImportedFEComponentCompoundDynamicAnalysis))
        return value



'''_3652.py

GearMeshCompoundParametricStudyTool
'''


from mastapy.system_model.analyses_and_results.parametric_study_tools.compound import _3659
from mastapy._internal.python_net import python_net_import

_GEAR_MESH_COMPOUND_PARAMETRIC_STUDY_TOOL = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools.Compound', 'GearMeshCompoundParametricStudyTool')


__docformat__ = 'restructuredtext en'
__all__ = ('GearMeshCompoundParametricStudyTool',)


class GearMeshCompoundParametricStudyTool(_3659.InterMountableComponentConnectionCompoundParametricStudyTool):
    '''GearMeshCompoundParametricStudyTool

    This is a mastapy class.
    '''

    TYPE = _GEAR_MESH_COMPOUND_PARAMETRIC_STUDY_TOOL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearMeshCompoundParametricStudyTool.TYPE'):
        super().__init__(instance_to_wrap)



'''_2150.py

PartDetailConfiguration
'''


from typing import (
    Callable, List, Generic, TypeVar
)

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy.system_model.part_model import _2009
from mastapy._internal.python_net import python_net_import

_PART_DETAIL_CONFIGURATION = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Configurations', 'PartDetailConfiguration')


__docformat__ = 'restructuredtext en'
__all__ = ('PartDetailConfiguration',)


TPartDetailSelection = TypeVar('TPartDetailSelection', bound='')
TPart = TypeVar('TPart', bound='_2009.Part')
TSelectableItem = TypeVar('TSelectableItem')


class PartDetailConfiguration(_0.APIBase, Generic[TPartDetailSelection, TPart, TSelectableItem]):
    '''PartDetailConfiguration

    This is a mastapy class.

    Generic Types:
        TPartDetailSelection
        TPart
        TSelectableItem
    '''

    TYPE = _PART_DETAIL_CONFIGURATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PartDetailConfiguration.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def delete_configuration(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'DeleteConfiguration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DeleteConfiguration

    @property
    def select_configuration(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'SelectConfiguration' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SelectConfiguration

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.'''

        return self.wrapped.Name

    @name.setter
    def name(self, value: 'str'):
        self.wrapped.Name = str(value) if value else None

    @property
    def selections(self) -> 'List[TPartDetailSelection]':
        '''List[TPartDetailSelection]: 'Selections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Selections, constructor.new(TPartDetailSelection))
        return value



'''_578.py

ConicalSetMicroGeometryConfigBase
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears import _128
from mastapy.gears.analysis import _962
from mastapy._internal.python_net import python_net_import

_CONICAL_SET_MICRO_GEOMETRY_CONFIG_BASE = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Bevel', 'ConicalSetMicroGeometryConfigBase')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalSetMicroGeometryConfigBase',)


class ConicalSetMicroGeometryConfigBase(_962.GearSetImplementationDetail):
    '''ConicalSetMicroGeometryConfigBase

    This is a mastapy class.
    '''

    TYPE = _CONICAL_SET_MICRO_GEOMETRY_CONFIG_BASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalSetMicroGeometryConfigBase.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def compound_layer_thickness(self) -> 'float':
        '''float: 'CompoundLayerThickness' is the original name of this property.'''

        return self.wrapped.CompoundLayerThickness

    @compound_layer_thickness.setter
    def compound_layer_thickness(self, value: 'float'):
        self.wrapped.CompoundLayerThickness = float(value) if value else 0.0

    @property
    def number_of_points_for_interpolated_surface_u(self) -> 'int':
        '''int: 'NumberOfPointsForInterpolatedSurfaceU' is the original name of this property.'''

        return self.wrapped.NumberOfPointsForInterpolatedSurfaceU

    @number_of_points_for_interpolated_surface_u.setter
    def number_of_points_for_interpolated_surface_u(self, value: 'int'):
        self.wrapped.NumberOfPointsForInterpolatedSurfaceU = int(value) if value else 0

    @property
    def number_of_points_for_interpolated_surface_v(self) -> 'int':
        '''int: 'NumberOfPointsForInterpolatedSurfaceV' is the original name of this property.'''

        return self.wrapped.NumberOfPointsForInterpolatedSurfaceV

    @number_of_points_for_interpolated_surface_v.setter
    def number_of_points_for_interpolated_surface_v(self, value: 'int'):
        self.wrapped.NumberOfPointsForInterpolatedSurfaceV = int(value) if value else 0

    @property
    def write_contact_chart_to_file_after_solve(self) -> 'bool':
        '''bool: 'WriteContactChartToFileAfterSolve' is the original name of this property.'''

        return self.wrapped.WriteContactChartToFileAfterSolve

    @write_contact_chart_to_file_after_solve.setter
    def write_contact_chart_to_file_after_solve(self, value: 'bool'):
        self.wrapped.WriteContactChartToFileAfterSolve = bool(value) if value else False

    @property
    def file_location_for_contact_chart(self) -> 'str':
        '''str: 'FileLocationForContactChart' is the original name of this property.'''

        return self.wrapped.FileLocationForContactChart

    @file_location_for_contact_chart.setter
    def file_location_for_contact_chart(self, value: 'str'):
        self.wrapped.FileLocationForContactChart = str(value) if value else None

    @property
    def deflection_from_bending_option(self) -> '_128.DeflectionFromBendingOption':
        '''DeflectionFromBendingOption: 'DeflectionFromBendingOption' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.DeflectionFromBendingOption)
        return constructor.new(_128.DeflectionFromBendingOption)(value) if value else None

    @deflection_from_bending_option.setter
    def deflection_from_bending_option(self, value: '_128.DeflectionFromBendingOption'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.DeflectionFromBendingOption = value

    @property
    def single_tooth_stiffness(self) -> 'float':
        '''float: 'SingleToothStiffness' is the original name of this property.'''

        return self.wrapped.SingleToothStiffness

    @single_tooth_stiffness.setter
    def single_tooth_stiffness(self, value: 'float'):
        self.wrapped.SingleToothStiffness = float(value) if value else 0.0

    @property
    def number_of_rows_for_flank_grid(self) -> 'int':
        '''int: 'NumberOfRowsForFlankGrid' is the original name of this property.'''

        return self.wrapped.NumberOfRowsForFlankGrid

    @number_of_rows_for_flank_grid.setter
    def number_of_rows_for_flank_grid(self, value: 'int'):
        self.wrapped.NumberOfRowsForFlankGrid = int(value) if value else 0

    @property
    def number_of_columns_for_grid(self) -> 'int':
        '''int: 'NumberOfColumnsForGrid' is the original name of this property.'''

        return self.wrapped.NumberOfColumnsForGrid

    @number_of_columns_for_grid.setter
    def number_of_columns_for_grid(self, value: 'int'):
        self.wrapped.NumberOfColumnsForGrid = int(value) if value else 0

    @property
    def number_of_rows_for_fillet_grid(self) -> 'int':
        '''int: 'NumberOfRowsForFilletGrid' is the original name of this property.'''

        return self.wrapped.NumberOfRowsForFilletGrid

    @number_of_rows_for_fillet_grid.setter
    def number_of_rows_for_fillet_grid(self, value: 'int'):
        self.wrapped.NumberOfRowsForFilletGrid = int(value) if value else 0



'''_6068.py

ClutchHalfLoadCase
'''


from mastapy.system_model.part_model.couplings import _2114
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6086
from mastapy._internal.python_net import python_net_import

_CLUTCH_HALF_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'ClutchHalfLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('ClutchHalfLoadCase',)


class ClutchHalfLoadCase(_6086.CouplingHalfLoadCase):
    '''ClutchHalfLoadCase

    This is a mastapy class.
    '''

    TYPE = _CLUTCH_HALF_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ClutchHalfLoadCase.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2114.ClutchHalf':
        '''ClutchHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2114.ClutchHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None



'''_2130.py

RollingRing
'''


from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.gears import _136
from mastapy.system_model.part_model.couplings import _2119
from mastapy._internal.python_net import python_net_import

_ROLLING_RING = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Couplings', 'RollingRing')


__docformat__ = 'restructuredtext en'
__all__ = ('RollingRing',)


class RollingRing(_2119.CouplingHalf):
    '''RollingRing

    This is a mastapy class.
    '''

    TYPE = _ROLLING_RING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'RollingRing.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def average_diameter(self) -> 'float':
        '''float: 'AverageDiameter' is the original name of this property.'''

        return self.wrapped.AverageDiameter

    @average_diameter.setter
    def average_diameter(self, value: 'float'):
        self.wrapped.AverageDiameter = float(value) if value else 0.0

    @property
    def largest_end(self) -> '_136.Hand':
        '''Hand: 'LargestEnd' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.LargestEnd)
        return constructor.new(_136.Hand)(value) if value else None

    @largest_end.setter
    def largest_end(self, value: '_136.Hand'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.LargestEnd = value

    @property
    def width(self) -> 'float':
        '''float: 'Width' is the original name of this property.'''

        return self.wrapped.Width

    @width.setter
    def width(self, value: 'float'):
        self.wrapped.Width = float(value) if value else 0.0

    @property
    def is_internal(self) -> 'bool':
        '''bool: 'IsInternal' is the original name of this property.'''

        return self.wrapped.IsInternal

    @is_internal.setter
    def is_internal(self, value: 'bool'):
        self.wrapped.IsInternal = bool(value) if value else False



'''_3902.py

HypoidGearSetCompoundModalAnalysesAtStiffnesses
'''


from typing import List

from mastapy.system_model.part_model.gears import _2074
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses_at_stiffnesses_ns.compound import _3900, _3901, _3849
from mastapy.system_model.analyses_and_results.modal_analyses_at_stiffnesses_ns import _3779
from mastapy._internal.python_net import python_net_import

_HYPOID_GEAR_SET_COMPOUND_MODAL_ANALYSES_AT_STIFFNESSES = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtStiffnessesNS.Compound', 'HypoidGearSetCompoundModalAnalysesAtStiffnesses')


__docformat__ = 'restructuredtext en'
__all__ = ('HypoidGearSetCompoundModalAnalysesAtStiffnesses',)


class HypoidGearSetCompoundModalAnalysesAtStiffnesses(_3849.AGMAGleasonConicalGearSetCompoundModalAnalysesAtStiffnesses):
    '''HypoidGearSetCompoundModalAnalysesAtStiffnesses

    This is a mastapy class.
    '''

    TYPE = _HYPOID_GEAR_SET_COMPOUND_MODAL_ANALYSES_AT_STIFFNESSES

    __hash__ = None

    def __init__(self, instance_to_wrap: 'HypoidGearSetCompoundModalAnalysesAtStiffnesses.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2074.HypoidGearSet':
        '''HypoidGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2074.HypoidGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2074.HypoidGearSet':
        '''HypoidGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2074.HypoidGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def hypoid_gears_compound_modal_analyses_at_stiffnesses(self) -> 'List[_3900.HypoidGearCompoundModalAnalysesAtStiffnesses]':
        '''List[HypoidGearCompoundModalAnalysesAtStiffnesses]: 'HypoidGearsCompoundModalAnalysesAtStiffnesses' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidGearsCompoundModalAnalysesAtStiffnesses, constructor.new(_3900.HypoidGearCompoundModalAnalysesAtStiffnesses))
        return value

    @property
    def hypoid_meshes_compound_modal_analyses_at_stiffnesses(self) -> 'List[_3901.HypoidGearMeshCompoundModalAnalysesAtStiffnesses]':
        '''List[HypoidGearMeshCompoundModalAnalysesAtStiffnesses]: 'HypoidMeshesCompoundModalAnalysesAtStiffnesses' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.HypoidMeshesCompoundModalAnalysesAtStiffnesses, constructor.new(_3901.HypoidGearMeshCompoundModalAnalysesAtStiffnesses))
        return value

    @property
    def load_case_analyses_ready(self) -> 'List[_3779.HypoidGearSetModalAnalysesAtStiffnesses]':
        '''List[HypoidGearSetModalAnalysesAtStiffnesses]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_3779.HypoidGearSetModalAnalysesAtStiffnesses))
        return value

    @property
    def assembly_modal_analyses_at_stiffnesses_load_cases(self) -> 'List[_3779.HypoidGearSetModalAnalysesAtStiffnesses]':
        '''List[HypoidGearSetModalAnalysesAtStiffnesses]: 'AssemblyModalAnalysesAtStiffnessesLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyModalAnalysesAtStiffnessesLoadCases, constructor.new(_3779.HypoidGearSetModalAnalysesAtStiffnesses))
        return value



'''_5802.py

BeltConnectionDynamicAnalysis
'''


from mastapy.system_model.connections_and_sockets import _1832
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6055
from mastapy.system_model.analyses_and_results.dynamic_analyses import _5856
from mastapy._internal.python_net import python_net_import

_BELT_CONNECTION_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses', 'BeltConnectionDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltConnectionDynamicAnalysis',)


class BeltConnectionDynamicAnalysis(_5856.InterMountableComponentConnectionDynamicAnalysis):
    '''BeltConnectionDynamicAnalysis

    This is a mastapy class.
    '''

    TYPE = _BELT_CONNECTION_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltConnectionDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def connection_design(self) -> '_1832.BeltConnection':
        '''BeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1832.BeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6055.BeltConnectionLoadCase':
        '''BeltConnectionLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6055.BeltConnectionLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None



'''_1439.py

NodalComponent
'''


from mastapy.nodal_analysis.nodal_entities import _1441
from mastapy._internal.python_net import python_net_import

_NODAL_COMPONENT = python_net_import('SMT.MastaAPI.NodalAnalysis.NodalEntities', 'NodalComponent')


__docformat__ = 'restructuredtext en'
__all__ = ('NodalComponent',)


class NodalComponent(_1441.NodalEntity):
    '''NodalComponent

    This is a mastapy class.
    '''

    TYPE = _NODAL_COMPONENT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'NodalComponent.TYPE'):
        super().__init__(instance_to_wrap)



'''_1458.py

FEModelComponentDrawStyle
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_FE_MODEL_COMPONENT_DRAW_STYLE = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses', 'FEModelComponentDrawStyle')


__docformat__ = 'restructuredtext en'
__all__ = ('FEModelComponentDrawStyle',)


class FEModelComponentDrawStyle(_0.APIBase):
    '''FEModelComponentDrawStyle

    This is a mastapy class.
    '''

    TYPE = _FE_MODEL_COMPONENT_DRAW_STYLE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FEModelComponentDrawStyle.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def connectable_components(self) -> 'bool':
        '''bool: 'ConnectableComponents' is the original name of this property.'''

        return self.wrapped.ConnectableComponents

    @connectable_components.setter
    def connectable_components(self, value: 'bool'):
        self.wrapped.ConnectableComponents = bool(value) if value else False

    @property
    def solid_shafts(self) -> 'bool':
        '''bool: 'SolidShafts' is the original name of this property.'''

        return self.wrapped.SolidShafts

    @solid_shafts.setter
    def solid_shafts(self, value: 'bool'):
        self.wrapped.SolidShafts = bool(value) if value else False

    @property
    def solid_components(self) -> 'bool':
        '''bool: 'SolidComponents' is the original name of this property.'''

        return self.wrapped.SolidComponents

    @solid_components.setter
    def solid_components(self, value: 'bool'):
        self.wrapped.SolidComponents = bool(value) if value else False

    @property
    def transparent_model(self) -> 'bool':
        '''bool: 'TransparentModel' is the original name of this property.'''

        return self.wrapped.TransparentModel

    @transparent_model.setter
    def transparent_model(self, value: 'bool'):
        self.wrapped.TransparentModel = bool(value) if value else False



'''_856.py

LeadReliefWithDeviation
'''


from mastapy._internal import constructor
from mastapy.gears.gear_designs.cylindrical.micro_geometry import _866
from mastapy._internal.python_net import python_net_import

_LEAD_RELIEF_WITH_DEVIATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry', 'LeadReliefWithDeviation')


__docformat__ = 'restructuredtext en'
__all__ = ('LeadReliefWithDeviation',)


class LeadReliefWithDeviation(_866.ReliefWithDeviation):
    '''LeadReliefWithDeviation

    This is a mastapy class.
    '''

    TYPE = _LEAD_RELIEF_WITH_DEVIATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'LeadReliefWithDeviation.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def distance_along_face_width(self) -> 'float':
        '''float: 'DistanceAlongFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DistanceAlongFaceWidth

    @property
    def lead_relief(self) -> 'float':
        '''float: 'LeadRelief' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LeadRelief



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6232 import AbstractAssemblyAdvancedSystemDeflection
    from ._6233 import AbstractShaftOrHousingAdvancedSystemDeflection
    from ._6234 import AdvancedSystemDeflection
    from ._6235 import AdvancedSystemDeflectionOptions
    from ._6236 import AdvancedSystemDeflectionSubAnalysis
    from ._6237 import AGMAGleasonConicalGearAdvancedSystemDeflection
    from ._6238 import AGMAGleasonConicalGearMeshAdvancedSystemDeflection
    from ._6239 import AGMAGleasonConicalGearSetAdvancedSystemDeflection
    from ._6240 import AssemblyAdvancedSystemDeflection
    from ._6241 import BearingAdvancedSystemDeflection
    from ._6242 import BeltConnectionAdvancedSystemDeflection
    from ._6243 import BeltDriveAdvancedSystemDeflection
    from ._6244 import BevelDifferentialGearAdvancedSystemDeflection
    from ._6245 import BevelDifferentialGearMeshAdvancedSystemDeflection
    from ._6246 import BevelDifferentialGearSetAdvancedSystemDeflection
    from ._6247 import BevelDifferentialPlanetGearAdvancedSystemDeflection
    from ._6248 import BevelDifferentialSunGearAdvancedSystemDeflection
    from ._6249 import BevelGearAdvancedSystemDeflection
    from ._6250 import BevelGearMeshAdvancedSystemDeflection
    from ._6251 import BevelGearSetAdvancedSystemDeflection
    from ._6252 import BoltAdvancedSystemDeflection
    from ._6253 import BoltedJointAdvancedSystemDeflection
    from ._6254 import ClutchAdvancedSystemDeflection
    from ._6255 import ClutchConnectionAdvancedSystemDeflection
    from ._6256 import ClutchHalfAdvancedSystemDeflection
    from ._6257 import CoaxialConnectionAdvancedSystemDeflection
    from ._6258 import ComponentAdvancedSystemDeflection
    from ._6259 import ConceptCouplingAdvancedSystemDeflection
    from ._6260 import ConceptCouplingConnectionAdvancedSystemDeflection
    from ._6261 import ConceptCouplingHalfAdvancedSystemDeflection
    from ._6262 import ConceptGearAdvancedSystemDeflection
    from ._6263 import ConceptGearMeshAdvancedSystemDeflection
    from ._6264 import ConceptGearSetAdvancedSystemDeflection
    from ._6265 import ConicalGearAdvancedSystemDeflection
    from ._6266 import ConicalGearMeshAdvancedSystemDeflection
    from ._6267 import ConicalGearSetAdvancedSystemDeflection
    from ._6268 import ConnectionAdvancedSystemDeflection
    from ._6269 import ConnectorAdvancedSystemDeflection
    from ._6270 import CouplingAdvancedSystemDeflection
    from ._6271 import CouplingConnectionAdvancedSystemDeflection
    from ._6272 import CouplingHalfAdvancedSystemDeflection
    from ._6273 import CVTAdvancedSystemDeflection
    from ._6274 import CVTBeltConnectionAdvancedSystemDeflection
    from ._6275 import CVTPulleyAdvancedSystemDeflection
    from ._6276 import CylindricalGearAdvancedSystemDeflection
    from ._6277 import CylindricalGearMeshAdvancedSystemDeflection
    from ._6278 import CylindricalGearSetAdvancedSystemDeflection
    from ._6279 import CylindricalMeshedGearAdvancedSystemDeflection
    from ._6280 import CylindricalPlanetGearAdvancedSystemDeflection
    from ._6281 import DatumAdvancedSystemDeflection
    from ._6282 import ExternalCADModelAdvancedSystemDeflection
    from ._6283 import FaceGearAdvancedSystemDeflection
    from ._6284 import FaceGearMeshAdvancedSystemDeflection
    from ._6285 import FaceGearSetAdvancedSystemDeflection
    from ._6286 import FlexiblePinAssemblyAdvancedSystemDeflection
    from ._6287 import GearAdvancedSystemDeflection
    from ._6288 import GearMeshAdvancedSystemDeflection
    from ._6289 import GearSetAdvancedSystemDeflection
    from ._6290 import GuideDxfModelAdvancedSystemDeflection
    from ._6291 import HypoidGearAdvancedSystemDeflection
    from ._6292 import HypoidGearMeshAdvancedSystemDeflection
    from ._6293 import HypoidGearSetAdvancedSystemDeflection
    from ._6294 import ImportedFEComponentAdvancedSystemDeflection
    from ._6295 import InterMountableComponentConnectionAdvancedSystemDeflection
    from ._6296 import KlingelnbergCycloPalloidConicalGearAdvancedSystemDeflection
    from ._6297 import KlingelnbergCycloPalloidConicalGearMeshAdvancedSystemDeflection
    from ._6298 import KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection
    from ._6299 import KlingelnbergCycloPalloidHypoidGearAdvancedSystemDeflection
    from ._6300 import KlingelnbergCycloPalloidHypoidGearMeshAdvancedSystemDeflection
    from ._6301 import KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection
    from ._6302 import KlingelnbergCycloPalloidSpiralBevelGearAdvancedSystemDeflection
    from ._6303 import KlingelnbergCycloPalloidSpiralBevelGearMeshAdvancedSystemDeflection
    from ._6304 import KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection
    from ._6305 import UseLtcaInAsdOption
    from ._6306 import MassDiscAdvancedSystemDeflection
    from ._6307 import MeasurementComponentAdvancedSystemDeflection
    from ._6308 import MountableComponentAdvancedSystemDeflection
    from ._6309 import OilSealAdvancedSystemDeflection
    from ._6310 import PartAdvancedSystemDeflection
    from ._6311 import PartToPartShearCouplingAdvancedSystemDeflection
    from ._6312 import PartToPartShearCouplingConnectionAdvancedSystemDeflection
    from ._6313 import PartToPartShearCouplingHalfAdvancedSystemDeflection
    from ._6314 import PlanetaryConnectionAdvancedSystemDeflection
    from ._6315 import PlanetaryGearSetAdvancedSystemDeflection
    from ._6316 import PlanetCarrierAdvancedSystemDeflection
    from ._6317 import PointLoadAdvancedSystemDeflection
    from ._6318 import PowerLoadAdvancedSystemDeflection
    from ._6319 import PulleyAdvancedSystemDeflection
    from ._6320 import RollingRingAdvancedSystemDeflection
    from ._6321 import RollingRingAssemblyAdvancedSystemDeflection
    from ._6322 import RollingRingConnectionAdvancedSystemDeflection
    from ._6323 import RootAssemblyAdvancedSystemDeflection
    from ._6324 import ShaftAdvancedSystemDeflection
    from ._6325 import ShaftHubConnectionAdvancedSystemDeflection
    from ._6326 import ShaftToMountableComponentConnectionAdvancedSystemDeflection
    from ._6327 import SpecialisedAssemblyAdvancedSystemDeflection
    from ._6328 import SpiralBevelGearAdvancedSystemDeflection
    from ._6329 import SpiralBevelGearMeshAdvancedSystemDeflection
    from ._6330 import SpiralBevelGearSetAdvancedSystemDeflection
    from ._6331 import SpringDamperAdvancedSystemDeflection
    from ._6332 import SpringDamperConnectionAdvancedSystemDeflection
    from ._6333 import SpringDamperHalfAdvancedSystemDeflection
    from ._6334 import StraightBevelDiffGearAdvancedSystemDeflection
    from ._6335 import StraightBevelDiffGearMeshAdvancedSystemDeflection
    from ._6336 import StraightBevelDiffGearSetAdvancedSystemDeflection
    from ._6337 import StraightBevelGearAdvancedSystemDeflection
    from ._6338 import StraightBevelGearMeshAdvancedSystemDeflection
    from ._6339 import StraightBevelGearSetAdvancedSystemDeflection
    from ._6340 import StraightBevelPlanetGearAdvancedSystemDeflection
    from ._6341 import StraightBevelSunGearAdvancedSystemDeflection
    from ._6342 import SynchroniserAdvancedSystemDeflection
    from ._6343 import SynchroniserHalfAdvancedSystemDeflection
    from ._6344 import SynchroniserPartAdvancedSystemDeflection
    from ._6345 import SynchroniserSleeveAdvancedSystemDeflection
    from ._6346 import TorqueConverterAdvancedSystemDeflection
    from ._6347 import TorqueConverterConnectionAdvancedSystemDeflection
    from ._6348 import TorqueConverterPumpAdvancedSystemDeflection
    from ._6349 import TorqueConverterTurbineAdvancedSystemDeflection
    from ._6350 import TransmissionErrorToOtherPowerLoad
    from ._6351 import UnbalancedMassAdvancedSystemDeflection
    from ._6352 import UseVariableBearingStiffnessOptions
    from ._6353 import VirtualComponentAdvancedSystemDeflection
    from ._6354 import WormGearAdvancedSystemDeflection
    from ._6355 import WormGearMeshAdvancedSystemDeflection
    from ._6356 import WormGearSetAdvancedSystemDeflection
    from ._6357 import ZerolBevelGearAdvancedSystemDeflection
    from ._6358 import ZerolBevelGearMeshAdvancedSystemDeflection
    from ._6359 import ZerolBevelGearSetAdvancedSystemDeflection
